@@ -9,7 +9,7 @@
 
 from __future__ import with_statement
 
-__version__ = '0.5.9'
+__version__ = '0.5.11'
 
 # import sip
 # sip.setapi('QString', 2)
@@ -19,7 +19,7 @@ from PySide.QtGui import QMainWindow, QHBoxLayout, QSizePolicy, QToolButton, \
     QVBoxLayout, QFileDialog, QDesktopServices, QScrollArea, QPushButton, \
     QToolBar, QLabel, QWidget, QInputDialog, QMenu, QAction, QApplication, \
     QIcon, QMessageBox, QPlainTextEdit
-from PySide.QtCore import Qt, QUrl, QSettings, Slot, Signal
+from PySide.QtCore import Qt, QUrl, QSettings, Slot, Signal, QTimer
 from PySide.QtMaemo5 import *
 from qbadgebutton import QToolBadgeButton
 
@@ -35,8 +35,11 @@ from settings import KhweeteurPref
 from dbusobj import KhweeteurDBus
 import re
 
-from QtMobility.Location import *
-
+try:
+    from QtMobility.Location import QGeoPositionInfoSource
+except:
+    print 'Pysode QtMobility not installed or broken'
+    
 class KhweeteurDBusHandler(dbus.service.Object):
 
     def __init__(self, parent):
@@ -444,10 +447,13 @@ class KhweeteurWin(QMainWindow):
 
         self.switch_tb_default()
 
-        self.model.load('HomeTimeline')
         self.setWindowTitle('Khweeteur : Home')
         self.setCentralWidget(self.view)
+        QTimer.singleShot(100,self.post_init)
 
+    @Slot()
+    def post_init(self):
+        self.model.load('HomeTimeline')
         self.geolocDoStart()
 
     @Slot()
@@ -866,14 +872,42 @@ class KhweeteurWin(QMainWindow):
         self.tb_charCounter.setText(unicode(140
                                     - len(local_self.toPlainText())))
         doc = local_self.document()
-        s = doc.size()
-        s.setHeight((s.height() + 1) * (local_self.fontMetrics().lineSpacing()
-                    + 1) - 21)
+        fm = local_self.fontMetrics()
+#        line_height = fm.boundingRect(local_self.toPlainText()).height()
+
+#        height = (line_height ) * doc.documentLayout().documentSize().height() + fm.lineSpacing()
+#        s = doc.documentLayout().documentSize()
+
+#        print 'Doc size', doc.size().height()
+
+#        doc.setHeight(s.height())
+#        s.setHeight((s.height() + 2) + (local_self.fontMetrics().lineSpacing()*2 + 2))
+#        s.setHeight(s.height())
+#        print 'Doc size', s.height()
+#        fr = local_self.frameRect()
+#        print 'frame size', fr.size().height()
+#        cr = local_self.contentsRect()
+#        print 'content size', cr.size().height()
+#        print 'page size', doc.pageSize().height()
+#        print 'page count', doc.pageCount()
+#        local_self.setFixedHeight(min(370, s.height() + fr.height()
+#                                  - cr.height() - 1))
+#        text_height = fm.boundingRect(0,0,local_self.size().width(),370, \
+#                    int(Qt.AlignTop) | int(Qt.AlignLeft) | int(Qt.TextWordWrap), \
+#                    local_self.toPlainText()).height()
+#        print 'text height',text_height
+#        if height > 5 :
+#        local_self.setFixedHeight(min(370, text_height + (fr.height() - cr.height()) + 6))
+#        local_self.updateGeometry()
+#Resize
+#        doc = self.document()            
+        s = doc.size().toSize()
+        s.setHeight((s.height() + 1) * (fm.lineSpacing()+1))
         fr = local_self.frameRect()
         cr = local_self.contentsRect()
-        local_self.setFixedHeight(min(370, s.height() + fr.height()
-                                  - cr.height() - 1))
-
+        local_self.setFixedHeight(min(s.height() +  (fr.height() - cr.height() - 1) - 15,370))
+        local_self.updateGeometry()
+        
     def loadSearchMenu(self):
         settings = QSettings()
         self.tb_search_menu.clear()
@@ -975,16 +1009,21 @@ class KhweeteurWin(QMainWindow):
         settings = QSettings()
         self.geoloc_source = None
         if settings.contains('useGPS'):
-            if settings.value('useGPS') == 'true':
+            if settings.value('useGPS') == '2':
                 self.geolocStart()
+            else:
+                self.geolocStop()
 
     def geolocStart(self):
         '''Start the GPS with a 50000 refresh_rate'''
-
         self.geoloc_coordinates = None
         if self.geoloc_source is None:
-            self.geoloc_source = \
-                QGeoPositionInfoSource.createDefaultSource(None)
+            try:
+                self.geoloc_source = \
+                    QGeoPositionInfoSource.createDefaultSource(None)
+            except:
+                self.geoloc_source = None
+                print 'PySide QtMobility not installed or package broken'
             if self.geoloc_source is not None:
                 self.geoloc_source.setUpdateInterval(50000)
                 self.geoloc_source.positionUpdated.connect(self.geolocUpdated)
